@@ -4,6 +4,10 @@ test_that("libgeos_version() works", {
 })
 
 test_that("GEOSversion() can be called from Rcpp", {
+  # these tests run a bit of Rcpp code that, depending on the Rcpp version,
+  # can lead to sanitizer errors that are out of my control
+  skip_on_cran()
+
   cache <- source_rcpp_libgeos('
     // [[Rcpp::export]]
     std::string version() {
